@@ -46,6 +46,7 @@ from ..responses import (
     PopularWordsResponse,
     PolicyAgreementsResponse,
 )
+from ..types import ImageType
 from ..utils import is_valid_image_format, get_hashed_filename, generate_uuid
 
 
@@ -236,10 +237,11 @@ class MiscAPI(object):
 
             image = Image.open(image_path)
             natural_width, natural_height = image.size
-            resized_image = image
 
-            if extension != ".gif":
-                resized_image.thumbnail((450, 450))
+            resized_image = Image.open(image_path)
+
+            if extension != ".gif" and image_type == ImageType.user_avatar:
+                resized_image.thumbnail((200, 200))
 
             original_attachment = Attachment(
                 file=image,
@@ -274,10 +276,13 @@ class MiscAPI(object):
             _files.append(thumbnail_attachment)
 
         file_names = [x.filename for x in _files]
-        res_presigned_url = self.get_file_upload_presigned_urls(file_names).presigned_urls
+        res_presigned_url = self.get_file_upload_presigned_urls(
+            file_names
+        ).presigned_urls
 
         res_upload = []
 
+        x: Attachment
         for x in _files:
             p_url = next(
                 (p.url for p in res_presigned_url if x.filename in p.filename), None
