@@ -218,7 +218,7 @@ class BaseClient(WebSocketInteractor):
         self.__max_retries: int = max_retries
         self.__backoff_factor: float = backoff_factor
         self.__wait_on_ratelimit: bool = wait_on_ratelimit
-        self.__last_request_timestamp: Optional[int] = None
+        self.__last_request_timestamp: int = 0
         self.__min_delay: float = min_delay
         self.__max_delay: float = max_delay
         self.__err_lang: str = err_lang
@@ -231,7 +231,7 @@ class BaseClient(WebSocketInteractor):
         )
 
         self.__header_interceptor: HeaderInterceptor = HeaderInterceptor(self.__cookie)
-        self.__header_interceptor.set_connection_speed("0")
+        self.__header_interceptor.set_connection_speed("0 kbps")
 
         self.__session: httpx.Client = httpx.Client(
             headers=self.__header_interceptor.intercept(),
@@ -409,7 +409,7 @@ class BaseClient(WebSocketInteractor):
 
             backoff_duration = self.__backoff_factor * (2**i)
 
-        self.__last_request_timestamp = None
+        self.__last_request_timestamp = 0
         if not bypass_delay:
             self.__last_request_timestamp = int(datetime.now().timestamp())
 
